<?php

declare(strict_types=1);
namespace App\Controller;

use App\JsonRpc\FooterServiceInterface;
use App\Tools\PublicData;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use App\Constants\ErrorCode;
/**
 * Class FooterController
 * @package App\Controller
 */

class FooterController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;

    /**
     * @var FooterServiceInterface
    */

    #[Inject]
    private $footerServiceClient;
     /**
     * 获取底部导航
     * @return array
     */
    public function getFooterCategory()
    {
        $requireData = $this->request->all();
        if(isset($requireData['website_name'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'website_name' =>'required|string|max:20',
                ],
                [
                    'website_name.required' => '网站名称不能为空',
                    'website_name.string' => '网站名称必须是字符串',
                    'website_name.max' => '网站名称不能超过20个字符',
                ]
            );
            if ($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['website_name'] = $requireData['website_name'];
        }
        if(isset($requireData['name'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'name' =>'required|string|max:20'
                ],
                [
                    'name.required' => '底部导航名称不能为空',
                    'name.string' => '底部导航名称必须是字符串',
                    'name.max' => '底部导航名称不能超过20个字符',
                ]
            );
            if ($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['name'] = $requireData['name'];
        }
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' =>'required|integer',
                'pageSize' =>'required|integer'
            ],
            [
                'page.required' => '第几页不能为空',
                'page.integer' => '第几页必须是整数',
                'pageSize.required' => '每页显示数量不能为空',
                'pageSize.integer' => '每页显示数量必须是整数'
            ]
        );
        if ($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $data['page'] = $requireData['page'];
        $data['pageSize'] = $requireData['pageSize'];
        // var_dump($data);
        $result = $this->footerServiceClient->getFooterCategory($data);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
        
    }
    /**
     * 添加底部导航
     * @return array
     */
    public function addFooterCategory()
    {
        $requireData = $this->request->all();
        if(!empty($requireData)){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'website_id' =>'required|integer',
                    'name' =>'required|string|max:20',
                    'type' =>'required|integer|in:0,1'
                ],
                [
                    'website_id.required' => '网站id不能为空',
                    'website_id.integer' => '网站id必须是整数',
                    'name.required' => '底部导航名称不能为空',
                    'name.string' => '底部导航名称必须是字符串',
                    'name.max' => '底部导航名称不能超过20个字符',
                    'type.required' => '底部导航类型不能为空',
                    'type.integer' => '底部导航类型必须是整数',
                    'type.in' => '底部导航类型必须是0或1'
                ]
            );
            if ($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data = $requireData;
        }else{
           $data = []; 
        }
        $result = $this->footerServiceClient->addFooterCategory($data);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
    /**
     * 修改底部导航
     * @return array
     */
    public function upFooterCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' =>'required|integer'
            ],
            [
                'id.required' => '底部导航id不能为空',
                'id.integer' => '底部导航id必须是整数'
            ]
        );
        if ($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if(isset($requireData['name']) || isset($requireData['website_id'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'name' =>'required|string|max:20' 
                ],
                [
                    'name.required' => '底部导航名称不能为空',
                    'name.string' => '底部导航名称必须是字符串',
                    'name.max' => '底部导航名称不能超过20个字符'
                ]
            );
            if ($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['name'] = $requireData['name'];
        }
        if(isset($requireData['website_id'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'website_id' =>'required|integer'
                ],
                [
                    'website_id.required' => '网站id不能为空',
                    'website_id.integer' => '网站id必须是整数'
                ]
            );
            if ($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
             $data['website_id'] = $requireData['website_id'];
        }
       
        $data['id'] = $requireData['id'];
        // var_dump($data);
        $result = $this->footerServiceClient->upFooterCategory($data);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }        
    }    
     /**
     * 删除底部导航
     * @return array
     */
    public function delFooterCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' =>'required|integer'
            ],
            [
                'id.required' => '底部导航id不能为空',
                'id.integer' => '底部导航id必须是整数'
            ]
        );
        $data['id'] = $requireData['id'];
        if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->footerServiceClient->delFooterCategory($data);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
     /**
     * 添加底部导航（列表）内容
     * @return array
     */
    public function addFooterContent()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'type' =>'required|integer|in:0,1',
                'fcat_id' =>'required|integer',
                'con_title' =>'required|string',
                'content' =>'required|string'
            ],
            [
                'type.required' => '底部导航类型不能为空',
                'type.integer' => '底部导航类型必须是整数',
                'type.in' => '底部导航类型必须是0或1',
                'fcat_id.required' => '底部导航id不能为空',
                'fcat_id.integer' => '底部导航id必须是整数',
                'con_title.required' => '内容标题不能为空',
                'con_title.string' => '内容标题必须是字符串',
                'content.required' => '内容不能为空',
                'content.string' => '内容必须是字符串'
            ]
        );
        if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $data['type'] = $requireData['type'];
        $data['fcat_id'] = $requireData['fcat_id'];
        $data['con_title'] = $requireData['con_title'];
        $data['content'] = $requireData['content'];
        if(isset($requireData['list_title'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'list_title' =>'required|string'
                ],
                [
                    'list_title.required' => '列表标题不能为空',
                    'list_title.string' => '列表标题必须是字符串'
                ]
            );
            if($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['list_title'] = $requireData['list_title'];
        }
        // return Result::success($data);
        $result = $this->footerServiceClient->addFooterContent($data);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
     /**
     * 获取并搜索底部导航（列表）内容
     * @return array
     */
    public function getFooterContent()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'fcat_id' =>'required|integer',
                'page' =>'required|integer',
                'pageSize' =>'required|integer'
            ],
            [
                'fcat_id.required' => '底部导航id不能为空',
                'fcat_id.integer' => '底部导航id必须是整数',
                'page.required' => '第几页不能为空',
                'page.integer' => '第几页必须是整数',
                'pageSize.required' => '每页显示数量不能为空',
                'pageSize.integer' => '每页显示数量必须是整数'
            ]
        );
        if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        if(isset($requireData['list_title'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'list_title' =>'required|string|max:30'
                ],
                [
                    'list_title.required' => '列表标题不能为空',
                    'list_title.string' => '列表标题必须是字符串',
                    'list_title.max' => '列表标题不能超过30个字符'
                ]
            );
            
            if($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['list_title'] = $requireData['list_title'];
        }
        if(isset($requireData['con_title'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'con_title' =>'required|string'
                ],
                [
                    'con_title.required' => '内容标题不能为空',
                    'con_title.string' => '内容标题必须是字符串'
                ]
            );
            if($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['con_title'] = $requireData['con_title'];
        }
        
        $data['fcat_id'] = $requireData['fcat_id'];
        $data['page'] = $requireData['page'];
        $data['pageSize'] = $requireData['pageSize'];
        $result = $this->footerServiceClient->getFooterContent($data);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
     /**
     * 获取某个底部导航（列表）内容
     * @return array
     */
    public function getOneFooterContent()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' =>'required|integer'
            ],
            [
                'id.required' => '底部导航内容id不能为空',
                'id.integer' => '底部导航内容id必须是整数'
            ]
        );
        if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $data['id'] = $requireData['id'];
       if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        // var_dump($data);
        $result = $this->footerServiceClient->getOneFooterContent($data);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
     /**
     * 修改底部导航（列表）内容
     * @return array
     */
    public function upFooterContent()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' =>'required|integer',
                'type' =>'required|integer|in:0,1',
                'con_title' =>'required|string',
                'content' =>'required|string'
            ],
            [
                'id.required' => '底部导航内容id不能为空',
                'id.integer' => '底部导航内容id必须是整数',
                'type.required' => '底部导航类型不能为空',
                'type.integer' => '底部导航类型必须是整数',
                'type.in' => '底部导航类型必须是0或1',
                'con_title.required' => '内容标题不能为空',
                'con_title.string' => '内容标题必须是字符串',
                'content.required' => '内容不能为空',
                'content.string' => '内容必须是字符串'
            ]
        );
        if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $data['id'] = $requireData['id'];
        $data['type'] = $requireData['type'];
        $data['con_title'] = $requireData['con_title'];
        $data['content'] = $requireData['content'];
        if(isset($requireData['list_title'])){
            $validator = $this->validationFactory->make(
                $requireData,
                [
                    'list_title' =>'required|string'
                ],
                [
                    'list_title.required' => '列表标题不能为空',
                    'list_title.string' => '列表标题必须是字符串'
                ]
            );
            if ($validator->fails()){
                $errorMessage = $validator->errors()->first();
                return Result::error($errorMessage);
            }
            $data['list_title'] = $requireData['list_title'];
        }
        // var_dump($data);
        $result = $this->footerServiceClient->upFooterContent($data);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
     /**
     * 删除底部导航（列表）内容
     * @return array
     */
    public function delFooterContent()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' =>'required|integer'
            ],
            [
                'id.required' => '底部导航id不能为空',
                'id.integer' => '底部导航id必须是整数'
            ]
        );
        if($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $data['id'] = $requireData['id'];
        // var_dump($data);
        $result = $this->footerServiceClient->delFooterContent($data);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }else{
            return Result::success($result['data']);
        }
    }
}